# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.djangoSqlInjection

Module implementing checks for potential SQL injections risks.

### Global Attributes

None

### Classes

None

### Functions

checkDjangoExtraUsed | Function to check for potential SQL injection on extra function.
checkDjangoRawSqlUsed | Function to check for potential SQL injection on RawSQL function.
getChecks | Public method to get a dictionary with checks handled by this module.
keywords2dict | Function to extract keywords arguments into a dictionary.

## checkDjangoExtraUsed

checkDjangoExtraUsed(reportError, context, _config)

Function to check for potential SQL injection on extra function.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## checkDjangoRawSqlUsed

checkDjangoRawSqlUsed(reportError, context, _config)

Function to check for potential SQL injection on RawSQL function.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up

## keywords2dict

keywords2dict(keywords)

Function to extract keywords arguments into a dictionary.

keywords (list of ast.keyword)
  list of keyword nodes

Return:
  dictionary with keyword name and value

Return Type:
  dict

Up